pub struct ExecutionOptions { /* private fields */ }Expand description
Options available when executing a job on a QPU.
Use Default to get a reasonable set of defaults, or start with ExecutionOptionsBuilder
to build a custom set of options.
Implementations
Sourceimpl ExecutionOptions
impl ExecutionOptions
Sourcepub fn builder() -> ExecutionOptionsBuilder
pub fn builder() -> ExecutionOptionsBuilder
Get an ExecutionOptionsBuilder that can be used to build a custom ExecutionOptions.
Sourcepub fn connection_strategy(&self) -> &ConnectionStrategy
pub fn connection_strategy(&self) -> &ConnectionStrategy
Get the ConnectionStrategy.
Sourcepub fn api_options(&self) -> Option<&InnerApiExecutionOptions>
pub fn api_options(&self) -> Option<&InnerApiExecutionOptions>
Get the ApiExecutionOptions.